#ifndef NT2_CORE_INCLUDE_FUNCTIONS_FIND_HPP_INCLUDED
#define NT2_CORE_INCLUDE_FUNCTIONS_FIND_HPP_INCLUDED

#include <nt2/core/functions/find.hpp>
#include <nt2/core/functions/expr/find.hpp>

#endif
